
prompt = {'Enter filename for photogate output','Threshold (0.3 or 1.0)'};
dlgtitle = 'Input';
dims = [1 35];
answer = inputdlg(prompt,dlgtitle,dims);
% 
data=load(answer{1});
thresh=str2double(answer{2});

%data=load('bouncing1.txt');
%thresh=1;

r=0.638; %radius of the spindle in cm

%remove the first point
data=data(2:end,:);
time=data(:,1); photo=data(:,2);
photo2=zeros(length(photo),1);

%converting the photogtae signal into a sequence of ones and zeros with a
%threshold of 1 V
for k=1:length(photo)
if photo(k)<thresh
    photo2(k)=0;
else
    photo2(k)=1;
end
end

%finding the indices where the transtitions from 0->1 and 1->0) occur
ind1=find(diff(photo2)==1);
ind2=find(diff(photo2)==-1);

%accounting for the data stream of binaries ending in a one instead of a
%zero

if length(ind1)>length(ind2)
ind1=ind1(1:end-1);
end

%Ensuring that the photogate output always starts with a zero

if length(ind1)<length(ind2)
ind2=ind2(1:end-1);
end


ind=[ind1 ind2];

%finding the intervals between successive crossings
ds1=diff(time(ind1+1));
ds2=diff(time(ind2));
dsfilt=sgolayfilt(ds1,7,11); %filtering the time intervals using Solvay Golay
omega=10*pi/(180)*1./dsfilt; %separation between two edges is 4+6=10 degrees

%finding the time where the average angular velocities are applicable
ind_avg=zeros(length(ind1)-1,1);
for k=1:length(ind1)-1
ind_avg(k)=round((ind1(k)+ind1(k+1))/2);
end
time_avg=time(ind_avg);

%%smoothing the angualr velocity data using a 23 point causal moving average
%%filter

windowWidth = 23; % Whatever you want.
kernel = ones(windowWidth,1) / windowWidth;
omegafilt=filter(kernel,1,omega);

%differentiating the filtered omega to determine the direction of the
%oscillation

omegadiff=diff(omegafilt);
omegadifffilt=filter(kernel,1,omegadiff);

%differentiation removes the first point, so let's make all vectors equal
%in length
omega=omega(2:end);
time_avg=time_avg(2:end);
omegafilt=omegafilt(2:end);

%Finally integrate the raw omega graph to obtain angles of rotation and
%depth

intomega=cumtrapz(time_avg,omega.*sign(omegadifffilt)); %integral of omega
intomega2=cumtrapz(time_avg,omega);
rev=intomega2/(2*pi); %number of revolutions 
height=-r*intomega;

figure; axis square; 

subplot (3,2,1);
plot(time_avg,omega), xlabel('time (s)'); ylabel('omega (rad/s)');
title('angular veclocity versus time'); grid on;

subplot(3,2,2);
plot(time_avg,omegafilt); xlabel('time (s)'); ylabel('omega (rad/s)');
title('filtered angular veclocity versus time'); grid on;

subplot(3,2,3);
plot(time_avg,omegadiff); xlabel('time (s)'); ylabel('alpha (rad/s^2)');
title('angular acceleration versus time'); grid on;

subplot(3,2,4);
plot(time_avg,omegadifffilt); 
hold on; plot(time_avg,sign(omegadifffilt));
xlabel('time (s)'); ylabel('alpha (rad/s^2)');
title('filtered angular acceleration versus time');
ylim([-1.2 1.2]); grid on;

subplot(3,2,5);
plot(time_avg,rev); xlabel('time (s)'); ylabel('revolutions');
title('revolutions (cw or ccw) versus time'); grid on;

subplot(3,2,6);
plot(time_avg,height); xlabel('time (s)'); ylabel('height (cm)');
title('depth versus time'); grid on;


